allocation_summary: Allocation Summary

View source: R/allocation_summary.R

allocation_summaryR Documentation

Allocation Summary

Description

Summarizes treatment allocations from a randomization schedule.

Usage

allocation_summary(schedule, group_col = "Group")

Arguments

schedule

A data frame or tibble produced by an ExpDesignR randomization function.

group_col

Name of the treatment group column.

Value

A tibble summarizing the number and percentage of subjects in each treatment group.

Examples

sch <- simple_randomization(
  n = 20,
  groups = c("Control","Treatment"),
  seed = 123
)

allocation_summary(sch)


ExpDesignR documentation built on Aug. 27, 2026, 5:06 p.m.