View source: R/allocation_summary.R
| allocation_summary | R Documentation |
Summarizes treatment allocations from a randomization schedule.
allocation_summary(schedule, group_col = "Group")
schedule |
A data frame or tibble produced by an ExpDesignR randomization function. |
group_col |
Name of the treatment group column. |
A tibble summarizing the number and percentage of subjects in each treatment group.
sch <- simple_randomization(
n = 20,
groups = c("Control","Treatment"),
seed = 123
)
allocation_summary(sch)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.