View source: R/block_randomization.R
| block_randomization | R Documentation |
Generates a randomized allocation schedule using fixed block randomization.
block_randomization(n, groups, block_size = 4, seed = NULL)
n |
Total number of subjects. |
groups |
Character vector of treatment groups. |
block_size |
Size of each block. Must be a multiple of the number of treatment groups. |
seed |
Optional random seed. |
A tibble with subject allocation.
block_randomization(
n = 24,
groups = c("Control","Treatment"),
block_size = 4,
seed = 123
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.